@@ -8,7 +8,7 @@ from openride.core.numba import (
     box_vertices,
 )
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from shapely import geometry
 
 import numpy as np
@@ -18,9 +18,17 @@ import numpy as np
 class BoundingBox(Geometry):
     """3D bounding box defined by a center position, rotation (euler angles) and size."""
 
-    position: Point = Point(0, 0, 0)
-    rotation: Rotation = Rotation(0, 0, 0)
-    size: Size = Size(1, 1, 1)
+    position: Point = field(default_factory=Point)
+    rotation: Rotation = field(default_factory=Rotation)
+    size: Size = field(default_factory=Size)
+
+    @classmethod
+    def from_raw(cls, 
+                 x:float=0.0, y:float=0.0, z:float=0.0, 
+                 roll:float=0.0, pitch:float=0.0, yaw:float=0.0, 
+                 sx:float=1.0, sy:float=1.0, sz:float=1.0,
+        ) -> 'BoundingBox':
+        return cls(Point(x, y, z), Rotation(roll, pitch, yaw), Size(sx, sy, sz))
 
     def to_shapely(self) -> geometry.Polygon:
         return geometry.Polygon(self.get_bird_eye_view_vertices())
