@@ -9,9 +9,11 @@ from openride.core.numba import (
     radius_of_curvature,
     vertices_to_distances,
     transform_vertices,
+    interpolate_line_index_at_xy,
+    project_point_on_line,
 )
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from shapely import geometry
 from typing import Tuple, Union, List, TYPE_CHECKING
 
@@ -25,7 +27,7 @@ if TYPE_CHECKING:
 @dataclass
 class Polyline(Geometry):
 
-    vertices: Union[np.ndarray, List[Point]] = np.empty((0, 3))
+    vertices: Union[np.ndarray, List[Point]] = field(default_factory=list)
 
     def __post_init__(self):
 
@@ -118,3 +120,9 @@ class Polyline(Geometry):
         if return_indices:
             return resampled, indices
         return resampled
+    
+    def get_index_at_point(self, point:Point) -> float:
+        return interpolate_line_index_at_xy(self.vertices, point.x, point.y)
+    
+    def project_point(self, point:Point) -> Point:
+        return Point(*project_point_on_line(self.vertices, point.x, point.y))
