@@ -1,13 +1,12 @@
 import openride as ride
-from openride.core.polyline import Polyline
 
 
 def main():
 
     viewer = ride.Viewer()
 
-    viewer.camera.set_position(ride.Point(-10, 0, 6))
-    viewer.camera.set_focus(ride.Point(4, 0, 0))
+    viewer.camera.set_position_xyz(-10, 0, 6)
+    viewer.camera.set_focus_xyz(4, 0, 0)
 
     viewer.hud.toggle_fps_count()
     viewer.hud.toggle_cursor_position()
@@ -30,10 +29,10 @@ def main():
     while True:
         viewer.draw_point(point, persist=False)
         viewer.labelize("allo", point)
-        viewer.draw_bounding_box(bounding_box, color=(0, 1, 0), alpha=0.75)
-        viewer.draw_model(ride.Category.Vehicle, bounding_box)
-        viewer.draw_polyline(polyline, color=(1, 0, 1), linewidth=3)
-        viewer.draw_polygon(polygon, color=(1, 0, 0), alpha=0.4)
+        viewer.draw_bounding_box(bounding_box, color=(0, 1, 0), alpha=0.35)
+        viewer.draw_model(ride.Category.Vehicle, bounding_box, color=(0,0,1))
+        viewer.draw_polyline(polyline, color=(1, 0, 1), linewidth=3, points_size=10)
+        viewer.draw_polygon(polygon, color=(1, 0, 0), alpha=0.7)
         viewer.update()
 
 
