@@ -1,6 +1,8 @@
 import time
 import vtk
 
+from typing import Any
+
 
 class Hud:
     def __init__(self, viewer, position=(0, 0)):
@@ -8,7 +10,7 @@ class Hud:
         self.viewer = viewer
         self.viewer.set_callback(self.update)
         self.position = position
-        self.time = time.time()
+        self.time = time.perf_counter()
         self._elements = {}
 
         self.text = vtk.vtkTextActor()
@@ -21,14 +23,15 @@ class Hud:
 
     def update(self):
         if self.fps_count:
-            self.add("fps", int(1 / (time.time() - self.time)))
+            self.add("fps", int(1 / (time.perf_counter() - self.time)))
         if self.cursor_position:
-            self.add("cursor", self.viewer.interactor.get_cursor_in_world())
+            cursor = self.viewer.interactor.get_cursor_in_world()
+            self.add("cursor", f"x:{cursor.x:.3f}, y:{cursor.y:.3f}, z:{cursor.z:.3f}")
         text = ""
         for element in self._elements:
             text += f"{element}: {str(self._elements[element])}\n"
         self.text.SetInput(text)
-        self.time = time.time()
+        self.time = time.perf_counter()
 
     def toggle_fps_count(self):
         self.fps_count = not self.fps_count
@@ -36,5 +39,5 @@ class Hud:
     def toggle_cursor_position(self):
         self.cursor_position = not self.cursor_position
 
-    def add(self, name, value):
-        self._elements[name] = value
+    def add(self, name:str, value:Any):
+        self._elements[name] = str(value)
