@@ -91,8 +91,6 @@ class Viewer:
         pcloud: PointCloud,
         color: tuple = None,
         colors: Iterable[float] = None,
-        colormap: str = "jet",
-        color_range: float = 2**16,
         size: int = 10,
         alpha: float = 1,
         persist: bool = False,
@@ -100,7 +98,7 @@ class Viewer:
         if color is None and colors is None:
             color = (1, 1, 1)
         actor = vtk_utils.get_point_cloud_actor(
-            pcloud.get_point_cloud(), colors, color, colormap, size, alpha, color_range
+            pcloud.get_point_cloud(), colors, color, size, alpha
         )
         self.render_actor(actor, persist)
 
@@ -133,7 +131,7 @@ class Viewer:
 
         if edge_color is not None:
             actor.GetProperty().SetEdgeVisibility(1)
-            actor.GetProperty().SetLineWidth(10)
+            actor.GetProperty().SetLineWidth(4)
             actor.GetProperty().SetEdgeColor(*edge_color)
 
         self.render_actor(actor, persist)
@@ -180,8 +178,12 @@ class Viewer:
         color: tuple = (1, 1, 1),
         alpha: float = 1,
         linewidth: int = 2,
+        points_size: Optional[int] = None,
         persist: bool = False,
     ):
+        if points_size:
+            self.draw_point_cloud(
+                PointCloud(line.vertices), color=color, size=points_size, alpha=alpha, persist=persist)
         actor = vtk_utils.get_line_actor(line.vertices, color, alpha, linewidth)
         self.render_actor(actor, persist)
 
