@@ -4,7 +4,6 @@ import numpy as np
 import vtk
 import vtk.util.numpy_support as vtk_np
 
-from matplotlib import cm
 from typing import List
 
 
@@ -157,10 +156,8 @@ def get_point_cloud_actor(
     vertices: np.ndarray,
     colors: np.ndarray = None,
     color: tuple = None,
-    colormap: str = "jet",
     size: int = 10,
     alpha: float = 1,
-    color_range: float = 2**16,
 ):
     polydata = vtk.vtkPolyData()
     actor = polydata_to_actor(polydata, alpha=alpha)
@@ -180,8 +177,6 @@ def get_point_cloud_actor(
     if color is None:
         vtkcolors = vtk.vtkUnsignedCharArray()
         vtkcolors.SetNumberOfComponents(3)
-        normalized_colors = np.log(1 + np.clip(colors, 0, np.inf)) / np.log(color_range)
-        colors = getattr(cm, colormap)(normalized_colors)[:, :3] * 255
         for i, p in enumerate(vertices):
             vtkcolors.InsertNextTuple(colors[i])
         polydata.GetCellData().SetScalars(vtkcolors)
